@@ -64,6 +64,7 @@ new DynamoDBStreamToLambdaToElasticSearchAndKibana(scope: Construct, id: string,
 |existingLambdaObj?|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Function.html)|Existing instance of Lambda Function object|
 |lambdaFunctionProps?|[`lambda.FunctionProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.FunctionProps.html)|Optional user provided props to override the default props for Lambda function|
 |dynamoTableProps?|[`dynamodb.TableProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-dynamodb.TableProps.html)|Optional user provided props to override the default props for DynamoDB Table|
+|existingTableObj?|[`dynamodb.Table`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-dynamodb.Table.html)|Existing instance of DynamoDB table object, If this is set then the dynamoTableProps is ignored|
 |dynamoEventSourceProps?|[`aws-lambda-event-sources.DynamoEventSourceProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda-event-sources.DynamoEventSourceProps.html)|Optional user provided props to override the default props for DynamoDB Event Source|
 |esDomainProps?|[`elasticsearch.CfnDomainProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-elasticsearch.CfnDomainProps.html)|Optional user provided props to override the default props for the Elasticsearch Service|
 |domainName|`string`|Domain name for the Cognito and the Elasticsearch Service|
@@ -140,7 +141,7 @@ import aws_cdk.core
 
 
 class DynamoDBStreamToLambdaToElasticSearchAndKibana(aws_cdk.core.Construct, metaclass=jsii.JSIIMeta, jsii_type="@aws-solutions-constructs/aws-dynamodb-stream-lambda-elasticsearch-kibana.DynamoDBStreamToLambdaToElasticSearchAndKibana"):
-    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, deploy_lambda: bool, domain_name: str, dynamo_event_source_props: typing.Optional[aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps]=None, dynamo_table_props: typing.Optional[aws_cdk.aws_dynamodb.TableProps]=None, es_domain_props: typing.Optional[aws_cdk.aws_elasticsearch.CfnDomainProps]=None, existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function]=None, lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps]=None) -> None:
+    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, deploy_lambda: bool, domain_name: str, dynamo_event_source_props: typing.Optional[aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps]=None, dynamo_table_props: typing.Optional[aws_cdk.aws_dynamodb.TableProps]=None, es_domain_props: typing.Optional[aws_cdk.aws_elasticsearch.CfnDomainProps]=None, existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function]=None, existing_table_obj: typing.Optional[aws_cdk.aws_dynamodb.Table]=None, lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps]=None) -> None:
         """
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
@@ -150,6 +151,7 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibana(aws_cdk.core.Construct, met
         :param dynamo_table_props: Optional user provided props to override the default props. Default: - Default props are used
         :param es_domain_props: Optional user provided props to override the default props for the API Gateway. Default: - Default props are used
         :param existing_lambda_obj: Existing instance of Lambda Function object. If ``deploy`` is set to false only then this property is required Default: - None
+        :param existing_table_obj: Existing instance of DynamoDB table object, If this is set then the dynamoTableProps is ignored. Default: - None
         :param lambda_function_props: Optional user provided props to override the default props. If ``deploy`` is set to true only then this property is required Default: - Default props are used
 
         access:
@@ -159,7 +161,7 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibana(aws_cdk.core.Construct, met
         summary:
         :summary:: Constructs a new instance of the LambdaToDynamoDB class.
         """
-        props = DynamoDBStreamToLambdaToElasticSearchAndKibanaProps(deploy_lambda=deploy_lambda, domain_name=domain_name, dynamo_event_source_props=dynamo_event_source_props, dynamo_table_props=dynamo_table_props, es_domain_props=es_domain_props, existing_lambda_obj=existing_lambda_obj, lambda_function_props=lambda_function_props)
+        props = DynamoDBStreamToLambdaToElasticSearchAndKibanaProps(deploy_lambda=deploy_lambda, domain_name=domain_name, dynamo_event_source_props=dynamo_event_source_props, dynamo_table_props=dynamo_table_props, es_domain_props=es_domain_props, existing_lambda_obj=existing_lambda_obj, existing_table_obj=existing_table_obj, lambda_function_props=lambda_function_props)
 
         jsii.create(DynamoDBStreamToLambdaToElasticSearchAndKibana, self, [scope, id, props])
 
@@ -199,9 +201,9 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibana(aws_cdk.core.Construct, met
         return jsii.get(self, "userPoolClient")
 
 
-@jsii.data_type(jsii_type="@aws-solutions-constructs/aws-dynamodb-stream-lambda-elasticsearch-kibana.DynamoDBStreamToLambdaToElasticSearchAndKibanaProps", jsii_struct_bases=[], name_mapping={'deploy_lambda': 'deployLambda', 'domain_name': 'domainName', 'dynamo_event_source_props': 'dynamoEventSourceProps', 'dynamo_table_props': 'dynamoTableProps', 'es_domain_props': 'esDomainProps', 'existing_lambda_obj': 'existingLambdaObj', 'lambda_function_props': 'lambdaFunctionProps'})
+@jsii.data_type(jsii_type="@aws-solutions-constructs/aws-dynamodb-stream-lambda-elasticsearch-kibana.DynamoDBStreamToLambdaToElasticSearchAndKibanaProps", jsii_struct_bases=[], name_mapping={'deploy_lambda': 'deployLambda', 'domain_name': 'domainName', 'dynamo_event_source_props': 'dynamoEventSourceProps', 'dynamo_table_props': 'dynamoTableProps', 'es_domain_props': 'esDomainProps', 'existing_lambda_obj': 'existingLambdaObj', 'existing_table_obj': 'existingTableObj', 'lambda_function_props': 'lambdaFunctionProps'})
 class DynamoDBStreamToLambdaToElasticSearchAndKibanaProps():
-    def __init__(self, *, deploy_lambda: bool, domain_name: str, dynamo_event_source_props: typing.Optional[aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps]=None, dynamo_table_props: typing.Optional[aws_cdk.aws_dynamodb.TableProps]=None, es_domain_props: typing.Optional[aws_cdk.aws_elasticsearch.CfnDomainProps]=None, existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function]=None, lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps]=None) -> None:
+    def __init__(self, *, deploy_lambda: bool, domain_name: str, dynamo_event_source_props: typing.Optional[aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps]=None, dynamo_table_props: typing.Optional[aws_cdk.aws_dynamodb.TableProps]=None, es_domain_props: typing.Optional[aws_cdk.aws_elasticsearch.CfnDomainProps]=None, existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function]=None, existing_table_obj: typing.Optional[aws_cdk.aws_dynamodb.Table]=None, lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps]=None) -> None:
         """
         :param deploy_lambda: Whether to create a new lambda function or use an existing lambda function. If set to false, you must provide a lambda function object as ``existingObj`` Default: - true
         :param domain_name: Cognito & ES Domain Name. Default: - None
@@ -209,6 +211,7 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibanaProps():
         :param dynamo_table_props: Optional user provided props to override the default props. Default: - Default props are used
         :param es_domain_props: Optional user provided props to override the default props for the API Gateway. Default: - Default props are used
         :param existing_lambda_obj: Existing instance of Lambda Function object. If ``deploy`` is set to false only then this property is required Default: - None
+        :param existing_table_obj: Existing instance of DynamoDB table object, If this is set then the dynamoTableProps is ignored. Default: - None
         :param lambda_function_props: Optional user provided props to override the default props. If ``deploy`` is set to true only then this property is required Default: - Default props are used
 
         summary:
@@ -226,6 +229,7 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibanaProps():
         if dynamo_table_props is not None: self._values["dynamo_table_props"] = dynamo_table_props
         if es_domain_props is not None: self._values["es_domain_props"] = es_domain_props
         if existing_lambda_obj is not None: self._values["existing_lambda_obj"] = existing_lambda_obj
+        if existing_table_obj is not None: self._values["existing_table_obj"] = existing_table_obj
         if lambda_function_props is not None: self._values["lambda_function_props"] = lambda_function_props
 
     @builtins.property
@@ -286,6 +290,15 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibanaProps():
         """
         return self._values.get('existing_lambda_obj')
 
+    @builtins.property
+    def existing_table_obj(self) -> typing.Optional[aws_cdk.aws_dynamodb.Table]:
+        """Existing instance of DynamoDB table object, If this is set then the dynamoTableProps is ignored.
+
+        default
+        :default: - None
+        """
+        return self._values.get('existing_table_obj')
+
     @builtins.property
     def lambda_function_props(self) -> typing.Optional[aws_cdk.aws_lambda.FunctionProps]:
         """Optional user provided props to override the default props.
